<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>AddAccountForm</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ui/addaccountform.ui" line="+14"/>
        <source>AddAccountForm</source>
        <translation>Добавяне на сметка</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Network name:</source>
        <translation>Име на мрежа:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Servers:</source>
        <translation>Сървъри:</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Add server</source>
        <translation>Добавяне на сървър</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Update server</source>
        <translation>Актуализиране на сървър</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Password:</source>
        <translation>Парола:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Server:</source>
        <translation>Сървър:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Protected by password</source>
        <translation>Защитен с парола</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Save password</source>
        <translation>Запис на паролата</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Secure Connection (SSL)</source>
        <translation>Защитена връзка (SSL)</translation>
    </message>
</context>
<context>
    <name>Author</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircplugin.cpp" line="+34"/>
        <source>Alexey Prokhin</source>
        <translation>Алексей Прохин</translation>
    </message>
</context>
<context>
    <name>EditNickForm</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ui/editnickform.ui" line="+14"/>
        <source>Form</source>
        <translation>Редактиране на псевдоним</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Nick:</source>
        <translation>Псевдоним:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Full name:</source>
        <translation>Пълно име:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Alternative nick:</source>
        <translation>Алтернативен псевдоним:</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>System</source>
        <translation>Системна</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Apple Roman</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Big5</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Big5-HKSCS</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>EUC-JP</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>EUC-KR</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>GB18030-0</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>IBM 850</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>IBM 866</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>IBM 874</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 2022-JP</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-1</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-2</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-3</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-4</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-5</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-6</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-7</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-8</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-9</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-10</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-13</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-14</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-15</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO 8859-16</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Iscii-Bng</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Iscii-Dev</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Iscii-Gjr</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Iscii-Knd</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Iscii-Mlm</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Iscii-Ori</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Iscii-Pnj</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Iscii-Tlg</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Iscii-Tml</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>JIS X 0201</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>JIS X 0208</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>KOI8-R</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>KOI8-U</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>MuleLao-1</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ROMAN8</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Shift-JIS</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>TIS-620</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>TSCII</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>UTF-8</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>UTF-16</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>UTF-16BE</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>UTF-16LE</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Windows-1250</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Windows-1251</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Windows-1252</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Windows-1253</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Windows-1254</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Windows-1255</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Windows-1256</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Windows-1257</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Windows-1258</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>WINSAMI2</source>
        <translation></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Password:</source>
        <translation>Парола:</translation>
    </message>
    <message>
        <location line="-363"/>
        <source>Encoding:</source>
        <translation>Кодировка:</translation>
    </message>
</context>
<context>
    <name>IRC</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircprotocol.cpp" line="+88"/>
        <source>Show console...</source>
        <translation>Показване на конзолата...</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Search channel...</source>
        <translation>Търсене на канал...</translation>
    </message>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircgroupchatmanager.cpp" line="+63"/>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Password</source>
        <translation>Парола</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Auto-join</source>
        <translation>Автоматично присъединяване</translation>
    </message>
</context>
<context>
    <name>IrcChannel</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircchannel.cpp" line="+374"/>
        <source>%1 gives channel operator privileges to %2.</source>
        <translation>%1 даде операторски права в канала на %2.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>%1 gives channel halfop privileges to %2.</source>
        <translation>%1 даде полуоператорски права в канала на %2.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>%1 gives %2 the permission to talk.</source>
        <translation>%1 даде на %2 право да говори.</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>%1 takes channel operator privileges from %2.</source>
        <translation>%1 отне операторските права в канала от %2.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>%1 takes channel halfop privileges from %2.</source>
        <translation>%1 отне полуоператорските права в канала от %2.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>%1 takes the permission to talk from %2.</source>
        <translation>%1 отне на %2 правото да говори.</translation>
    </message>
</context>
<context>
    <name>IrcChannelListForm</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ui/ircchannellist.ui" line="+14"/>
        <source>Form</source>
        <translation>Канали</translation>
    </message>
</context>
<context>
    <name>IrcConsoleForm</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ui/console.ui" line="+14"/>
        <source>IRC Server Console</source>
        <translation>Конзола на IRC сървъра</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircplugin.cpp" line="-3"/>
        <location line="+6"/>
        <source>IRC</source>
        <translation>IRC</translation>
    </message>
    <message>
        <location line="-5"/>
        <location line="+6"/>
        <source>Implementation of IRC protocol</source>
        <translation>Реализация на IRC протокола</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>IRC account creator</source>
        <translation>Създаване на IRC сметка</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Proxy support</source>
        <translation>Поддръжка на прокси</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proxy support for IRC protocol</source>
        <translation>Поддръжка на прокси за IRC протокола</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Account creator for IRC protocol</source>
        <translation>Създаване на сметка за IRC протокола</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/irccommandalias.cpp" line="+111"/>
        <source>Not enough parameters for command %1</source>
        <translation>Липсват достатъчно параметри за командата %1</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircprotocol.cpp" line="-31"/>
        <source>User information</source>
        <translation>Информация за потребителя</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Servers</source>
        <translation>Сървъри</translation>
    </message>
</context>
<context>
    <name>Task</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircplugin.cpp" line="-7"/>
        <source>Author</source>
        <translation>Автор</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::irc::ChannelsModel</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ui/ircchannellist.cpp" line="+81"/>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Users</source>
        <translation>Потребители</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Topic</source>
        <translation>Тема</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::irc::IrcAccount</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircaccount.cpp" line="+73"/>
        <source>Away</source>
        <translation>Отсъствам</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::irc::IrcChannel</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircchannel.cpp" line="-208"/>
        <source>You are now known as %1</source>
        <translation>В момента се подвизавате като %1</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 are now known as %2</source>
        <translation>%1 вече се подвизава като %2</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>%1 (%2) has joined the channel</source>
        <translation>%1 (%2) се присъедини към канала</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>You left this channel (%1)</source>
        <translation>Напуснахте канала (%1)</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>You left this channel</source>
        <translation>Напуснахте канала</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 has left this channel (%2)</source>
        <translation>%1 напусна канала (%2)</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>%1 has left this channel</source>
        <translation>%1 напусна канала</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>%1 has kicked you from the channel (%2)</source>
        <translation>%1 ви изрита от канала (%2)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 has kicked you from the channel</source>
        <translation>%1 ви изрита от канала</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>%1 has kicked %2 (%3)</source>
        <translation>%1 изрита %2 (%3)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 has kicked %2</source>
        <translation>%1 изрита %2</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>The channel topic is &quot;%1&quot;</source>
        <translation>Заглавието на канала е &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>The topic was set by %1 on %2.</source>
        <translation>Заглавието на канала е зададено от %1 на %2.</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::irc::IrcChannelListForm</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ui/ircchannellist.cpp" line="+93"/>
        <source>Fetching channels list...</source>
        <translation>Изтегляне на списъка с канали...</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Channels list loaded. (%1)</source>
        <translation>Списъкът с канали е зареден. (%1)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Fetching channels list... (%1)</source>
        <translation>Изтегляне на списъка с канали... (%1)</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::irc::IrcCommandAlias</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/irccommandalias.cpp" line="+89"/>
        <source>Kick / Ban</source>
        <translation>Изритване/Забрана</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kick</source>
        <translation>Изритване</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Kickban</source>
        <translation>Изритване със забрана</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ban</source>
        <translation>Забрана</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Ban *!*@*.host</source>
        <translation>Забрана *!*@*.host</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ban *!*@domain</source>
        <translation>Забрана *!*@domain</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ban *!user@*.host</source>
        <translation>Забрана *!user@*.host</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ban *!user@domain</source>
        <translation>Забрана *!user@domain</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kickban *!*@*.host</source>
        <translation>Изритване със забрана *!*@*.host</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Kickban *!*@domain</source>
        <translation>Изритване със забрана *!*@domain</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Kickban *!user@*.host</source>
        <translation>Изритване със забрана *!user@*.host</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Kickban *!user@domain</source>
        <translation>Изритване със забрана *!user@domain</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Ping</source>
        <translation></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Request client information</source>
        <translation>Заявка за информация за клиента</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Request version</source>
        <translation>Заявка за версия</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Request time</source>
        <translation>Заявка за време</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Avatar</source>
        <translation>Аватар</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Modes</source>
        <translation>Режими</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Give Op</source>
        <translation>Предоставяне на операторски права</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Take Op</source>
        <translation>Отнемане на операторските права</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Give HalfOp</source>
        <translation>Предоставяне на полуоператорски права</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Take HalfOp</source>
        <translation>Отнемане на полуоператорските права</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Give voice</source>
        <translation>Предоставяне на глас</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Take voice</source>
        <translation>Отнемане на глас</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Send WHOIS request</source>
        <translation>Изпращане WHOIS заявка</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::irc::IrcConnection</name>
    <message>
        <source>Kick / Ban</source>
        <translation type="obsolete">Изритване/Забрана</translation>
    </message>
    <message>
        <source>Kick</source>
        <translation type="obsolete">Изритване</translation>
    </message>
    <message>
        <source>Kickban</source>
        <translation type="obsolete">Изритване със забрана</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation type="obsolete">Забрана</translation>
    </message>
    <message>
        <source>Ban *!*@*.host</source>
        <translation type="obsolete">Забрана *!*@*.host</translation>
    </message>
    <message>
        <source>Ban *!*@domain</source>
        <translation type="obsolete">Забрана *!*@domain</translation>
    </message>
    <message>
        <source>Ban *!user@*.host</source>
        <translation type="obsolete">Забрана *!user@*.host</translation>
    </message>
    <message>
        <source>Ban *!user@domain</source>
        <translation type="obsolete">Забрана *!user@domain</translation>
    </message>
    <message>
        <source>Kickban *!*@*.host</source>
        <translation type="obsolete">Изритване със забрана *!*@*.host</translation>
    </message>
    <message>
        <source>Kickban *!*@domain</source>
        <translation type="obsolete">Изритване със забрана *!*@domain</translation>
    </message>
    <message>
        <source>Kickban *!user@*.host</source>
        <translation type="obsolete">Изритване със забрана *!user@*.host</translation>
    </message>
    <message>
        <source>Kickban *!user@domain</source>
        <translation type="obsolete">Изритване със забрана *!user@domain</translation>
    </message>
    <message>
        <source>Request client information</source>
        <translation type="obsolete">Заявка за информация за клиента</translation>
    </message>
    <message>
        <source>Request version</source>
        <translation type="obsolete">Заявка за версия</translation>
    </message>
    <message>
        <source>Request time</source>
        <translation type="obsolete">Заявка за време</translation>
    </message>
    <message>
        <source>Request avatar</source>
        <translation type="obsolete">Заявка за аватар</translation>
    </message>
    <message>
        <source>Modes</source>
        <translation type="obsolete">Режими</translation>
    </message>
    <message>
        <source>Give Op</source>
        <translation type="obsolete">Предоставяне на операторски права</translation>
    </message>
    <message>
        <source>Take Op</source>
        <translation type="obsolete">Отнемане на операторските права</translation>
    </message>
    <message>
        <source>Give HalfOp</source>
        <translation type="obsolete">Предоставяне на полуоператорски права</translation>
    </message>
    <message>
        <source>Take HalfOp</source>
        <translation type="obsolete">Отнемане на полуоператорските права</translation>
    </message>
    <message>
        <source>Give voice</source>
        <translation type="obsolete">Предоставяне на глас</translation>
    </message>
    <message>
        <source>Take voice</source>
        <translation type="obsolete">Отнемане на глас</translation>
    </message>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircconnection.cpp" line="+147"/>
        <source>Server %1 (Version %2), User modes: %3, Channel modes: %4</source>
        <translation>Сървър %1 (версия %2) Потребителски режими: %3, Режими на каналите: %4</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Message of the day:</source>
        <translation>Съобщение за деня:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>End of message of the day</source>
        <translation>Край на съобщението за деня</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Start of /LIST</source>
        <translation>Начало на /LIST</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>End of /LIST</source>
        <translation>Край на /LIST</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Bad list syntax, type /QUOTE HELP LIST</source>
        <translation>Грешен синтаксис, напишете /QUOTE HELP LIST</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Server load is temporarily too heavy.
Please wait a while and try again.</source>
        <translation>Временно сървърът е натоварен.
Моля, изчакайте малко и опитайте отново.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>%1 set away message &quot;%2&quot;</source>
        <translation>%1 зададе съобщение при отсъствие: &quot;%2&quot;</translation>
    </message>
    <message>
        <location line="+305"/>
        <source>SSL error: %1</source>
        <translation>SSL грешка: %1</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>SSL handshake completed</source>
        <translation>SSL handshake приключи</translation>
    </message>
    <message>
        <source>%1 set away message %2</source>
        <translation type="obsolete">%1 зададе съобщение при отсъствие: %2</translation>
    </message>
    <message>
        <location line="-307"/>
        <source>%1 removed away message</source>
        <translation>%1 премахна съобщението при отсъствие</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>You are no longer marked as being away</source>
        <translation>Вече не сте отбелязан(а) като отсъстващ(а)</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>You have been marked as being away</source>
        <translation>Отбелязан(а) сте като отсъстващ(а)</translation>
    </message>
    <message>
        <source>%1 is %2@%3 (%4)</source>
        <translation type="obsolete">%1 е %2@%3 (%4)</translation>
    </message>
    <message>
        <source>%1 is online via %2 (%3)</source>
        <translation type="obsolete">%1 е на линия през %2 (%3)</translation>
    </message>
    <message>
        <source>%1 is an IRC operator</source>
        <translation type="obsolete">%1 е IRC оператор</translation>
    </message>
    <message>
        <source>%1 has been idle since</source>
        <translation type="obsolete">%1 бездейства от</translation>
    </message>
    <message>
        <source>%1 has been online since</source>
        <translation type="obsolete">%1 е бил(а) на линия от</translation>
    </message>
    <message>
        <source>%1 is a user on channels: </source>
        <translation type="obsolete">%1 е потребител в следните канали: </translation>
    </message>
    <message>
        <source>%1 is logged in as %2</source>
        <translation type="obsolete">%1 се е вписал като %2</translation>
    </message>
    <message>
        <source>%1 is using a secure connection</source>
        <translation type="obsolete">%1 използва защитена връзка</translation>
    </message>
    <message numerus="yes">
        <source>Received CTCP-PING reply from %1: %2 seconds</source>
        <translation type="obsolete">
            <numerusform>Получен CTCP-PING отговор от %1: %2 секунда</numerusform>
            <numerusform>Получен CTCP-PING отговор от %1: %2 секунди</numerusform>
        </translation>
    </message>
    <message>
        <source>Received CTCP-%1 reply from %2: %3</source>
        <translation type="obsolete">Получен CTCP-%1 отговор от %2: %3</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>Add at least one server before connecting</source>
        <translation>Добавeте поне един сървър преди да се свържете</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Set at least one nick before connecting</source>
        <translation>Задайте поне един псевдоним преди да се свържете</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Cannot connect to %1 network</source>
        <translation>Невъзможно е свързването към мрежата %1</translation>
    </message>
    <message>
        <location line="+177"/>
        <source>Network error: %1</source>
        <translation>Мрежова грешка: %1</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::irc::IrcJoinLeftActionGenerator</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircchannel.cpp" line="-310"/>
        <source>Leave the channel</source>
        <translation>Напускане на канала</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Join the channel</source>
        <translation>Присъединяване към канала</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::irc::IrcProtocol</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircprotocol.cpp" line="+2"/>
        <source>Auto-join</source>
        <translation>Автоматично присъединяване</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::irc::IrcStandartCtpcHandler</name>
    <message numerus="yes">
        <location filename="../../qutim/protocols/irc/src/ircstandartctpchandler.cpp" line="+69"/>
        <source>Received CTCP-PING reply from %1: %2 seconds</source>
        <translation>
            <numerusform>Получен CTCP-PING отговор от %1: %2 секунда</numerusform>
            <numerusform>Получен CTCP-PING отговор от %1: %2 секунди</numerusform>
        </translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Received CTCP-%1 reply from %2: %3</source>
        <translation>Получен CTCP-%1 отговор от %2: %3</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::irc::IrcWhoisRepliesHandler</name>
    <message>
        <location filename="../../qutim/protocols/irc/src/ircwhoisreplieshandler.cpp" line="+53"/>
        <source>%1 is %2@%3 (%4)</source>
        <translation>%1 е %2@%3 (%4)</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>%1 is online via %2 (%3)</source>
        <translation>%1 е на линия през %2 (%3)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is an IRC operator</source>
        <translation>%1 е IRC оператор</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>%1 has been idle since</source>
        <translation>%1 бездейства от</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>%1 has been online since</source>
        <translation>%1 е бил(а) на линия от</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 is a user on channels: </source>
        <translation>%1 е потребител в следните канали: </translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is logged in as %2</source>
        <translation>%1 се е вписал като %2</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>%1 is using a secure connection</source>
        <translation>%1 използва защитена връзка</translation>
    </message>
</context>
</TS>
